check_zip: Does correctness check on the data file paths.

Description Usage Arguments Details Value Note

View source: R/check_zip.R

Description

Extracts data for a given meteorological station from the raw zip-archive loaded from meteo.ru into a regular dataframe. The dataframe columns names are being attempted to be automatically translated using the metadata.

Usage

1
check_zip(dir_name, zip_name)

Arguments

dir_name

The dir_name is the directory name where the original meteorological archive is stored. May be NULL if the zip_name contains the full path to the archive.

zip_name

The zip_name is the name of a specific zip-archive to be processed.

Details

An original structure of the data archive is kept and respected.

Value

Data path is returned.

Note

The raw meteorological records are supposed to be loaded via meteo.ru data access service with original zip archive names left.


ekatef/climaru documentation built on Dec. 20, 2021, 4:13 a.m.