read_meteo: Extract meteorological records from the raw meteorological...

Description Usage Arguments Details Value Note

View source: R/read_meteo.R

Description

Extracts data for a given meteorological station from the raw zip-archive loaded from meteo.ru into a regular dataframe. The dataframe columns names are being attempted to be automatically translated using the metadata.

Usage

1
read_meteo(dir_name, zip_name, st_id)

Arguments

dir_name

The dir_name is the directory name where the original meteorological archive is stored. May be NULL if the zip_name contains the full path to the archive.

zip_name

The zip_name is the name of a specific zip-archive to be processed.

st_id

The st_id is the name of the meteorological station to be read from the whole zip archive.

Details

The format of the st_id is the five-digits WMO sstation identifier like "12345". The list of stations may be found via meteo.ru/english/climate/katalog2.html

Value

A dataframe of the observed meteorological time series corresponding to the requested station. The columns names are set according to the meta-data file.

Note

The raw meteorological records are supposed to be loaded via meteo.ru data access service with original zip archive names left untouched. Yes, "wr56089a1.zip" is perfectly alright.


ekatef/climaru documentation built on Dec. 20, 2021, 4:13 a.m.