restore_meta: A function to automatically restore meta data for a selected...

Description Usage Arguments Details Value Examples

View source: R/restore_meta.R

Description

Translate raw meta information in plain English.

Usage

1
restore_meta(dir_name, zip_name)

Arguments

dir_name

The dir_name is the directory name where the original meteorological archive is stored. May be NULL if the zip_name contains the full path to the archive.

zip_name

The zip_name is a single name of a specific zip-archive to be processed. May contain a full path to a zip archive to be processed.

Details

The function is intended for use with the zip archive containing meteorological data available via meteo.ru.

The dir_name will be set to 'NULL' automatically with a warning in case the supplied zip_name is a folder path.

Value

A character vector containing the names of the data columns which are stored in the given zip arcive.

Examples

1
2
meteo_zip <- system.file("extdata", "wr56089.zip", package = "climaru")
data_chunk <- restore_meta(dir_name = NULL, zip_name = meteo_zip)

ekatef/climaru documentation built on Dec. 20, 2021, 4:13 a.m.