show_stations: A function to automatically restore meta data for a selected...

Description Usage Arguments Details Value

View source: R/show_stations.R

Description

Extract station identifiers contained in the records archive.

Usage

1
show_stations(st_ids, main_txt, sub_txt, x_range, y_range)

Arguments

st_ids

The st_ids is a vector of meteorological stations identifiers to be shown on the map.

main_txt

The main_txt is a text string to annotate the produced map.

sub_txt

The sub_txt is a text string to put additional information to the produced map.

x_range

The x_range is a latitude range to be shown.

y_range

The y_range is a lontitude range to be shown.

Details

The function is plot the requested stations.

Value

A plot


ekatef/climaru documentation built on Dec. 20, 2021, 4:13 a.m.