Description Usage Arguments Details Value References Examples
View source: R/translate_meta.R
Translate somewhat enigmatic meta information containing in the RIHMI WDC database to plain English.
1 | translate_meta(colnames_raw)
|
colnames_raw |
The character vector containing raw columns names of the data containing in the meteorologic zip archive. |
The function is intended for use on the zip archive loaded via meteo.ru. The original transliterated observations meta-information is transformed into a set of short notations. These notations are aimed to be used further as proper variables names or columns names and are thus shortened. Notations meaning is as follows:
"st_id" is an identifier of the meteorological station according to the World Meteorological Organization (WMO Station Number);
"year" is the year of the observation;
"month" is the month of the observation;
"day" is the day of the observation;
"t_quality_flag" is the quality flag of the temperature measurement;
"t_min" is the minimum temperature value;
"t_avr" is the average temperature value;
"t_max" is the maximum temperature value;
"pre" is the precipitation amount;
"h_snow" is the snow height;
"snow_cover" is the snow cover defined as a percentage of an area covered by snow;
"h_snow_details" is an additional information related to the snow height;
"h_snow_quality" is the quality flag of the snow height measurment;
"snow_tas_details is an additional information related to snow and the temperature conditions;
"year_Greenwich" is an observation year according to UTC;
"month_Greenwich" is an observation month according to UTC;
"day_Greenwich" is an observation day according to UTC;
"hour_Greenwich" is an observation hour according to UTC;
"year_local" is an observation year according to the local time;
"month_local" is an observation month according to the local time;
"day_local" is an observation day according to the local time;
"hour_local" is an observation hour according to the local time;
"i_obs_in_day" is number of the observation counted inside the day;
"time_local" is the local time of the observation;
"i_time_zone" a time zone number;
"day_start" a start of the meteorological day;
"i_atm_phen";
"code_atm_phen";
"intensity_atm_phen";
"begin_atm_phen";
"end_atm_phen";
"wind_direction";
"srfw" is the average surface wind speed;
"srfw_max" is the maximum surface wind speed;
"press_station" is the pressure on the station level;
"press_sl" is the sea level pressure;
"bar_tendency_character" is a baric tendency type;
"bar_tendency_value" is the baric tendency value;
"st_n_coordin" is a coordinate station number;
"tas_Xcm_onY" is the soil temperature on the X cm multiplied on Y;
"track_type" is the track type;
"snow_coverage_station is the snow cover value observed at the station;
"snow_coverage_track" is the snow cover value observed along the track;
"ice_coverage_track" is the ice layer height observed along the track;
"h_mean_snow_track_cm" is the mean snow level along the track in centimeters;
"h_max_snow_track_cm" is the maximun snow level along the track in centimeters;
"h_min_snow_track_cm" is the minimum snow level along the track [cm];
"snow_density" is the mean snow density;
"h_ice" is the mean thickness of the ice layer;
"h_humide_snow_mm" is the thickness of the snow saturated with water;
"h_water_mm" is the water level [mm];
"water_in_snow_mm" is the water amount in the snow [mm];
"overall_water_mm" is the overall water amount [mm];
"snow_cover_type" is the snow cover type;
"snow_type" is the snow type.
The list is currently under development to include more meteorological variables could be assessed via the RIHMI WDC data base. The "col_[[:digit:]]+" ("col_1", "col_2" etc) is used if the term is not available yet as a replacement of the initial notation.
The character vector of the data columns names translated in English if available. Raw column names are kept if the translation failed.
WMO stations list via UN data base http://data.un.org/Data.aspx?d=CLINO&f=ElementCode
Weather Reporting (2012) Volume A. Observing stations. Available via https://library.wmo.int/doc_num.php?explnum_id=9896
1 2 3 4 5 | translate_meta(c("Indeks VMO", "Mesyats", "God"))
meteo_zip <- system.file("extdata", "wr56089.zip", package = "climaru")
meta_info_raw <- restore_meta(dir_name = NULL, zip_name = meteo_zip)
meta_info_en <- translate_meta(meta_info_raw)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.