Description Usage Arguments Details Value Note
Extracts data for a given meteorological station from the raw zip-archive loaded from meteo.ru into a regular dataframe. The dataframe columns names are being attempted to be automatically translated using the metadata.
1 | check_zip(dir_name, zip_name)
|
dir_name |
The |
zip_name |
The |
An original structure of the data archive is kept and respected.
Data path is returned.
The raw meteorological records are supposed to be loaded via meteo.ru data access service with original zip archive names left.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.