Description Usage Arguments Details Value Note
Extracts data for a given meteorological station from the raw zip-archive loaded from meteo.ru into a regular dataframe. The dataframe columns names are being attempted to be automatically translated using the metadata.
1 | read_meteo(dir_name, zip_name, st_id)
|
dir_name |
The |
zip_name |
The |
st_id |
The |
The format of the st_id is the five-digits WMO sstation identifier like "12345". The list of stations may be found via meteo.ru/english/climate/katalog2.html
A dataframe of the observed meteorological time series corresponding to the requested station. The columns names are set according to the meta-data file.
The raw meteorological records are supposed to be loaded via meteo.ru data access service with original zip archive names left untouched. Yes, "wr56089a1.zip" is perfectly alright.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.