Description Usage Arguments Details Value Examples
View source: R/restore_st_ids.R
Extract station identifiers contained in the records archive.
1 | restore_st_ids(dir_name, zip_name)
|
dir_name |
The |
zip_name |
The |
The function is intended for use with the zip archive containing meteorological data available via meteo.ru.
May take quite long in case a single records file containing data for many stations.
The dir_name will be set to 'NULL' automatically with a warning in case the supplied zip_name is a folder path.
A character vector containing stations identifiers corresponding to the observations stored in the given zip arcive.
1 2 | meteo_zip <- system.file("extdata", "wr56089.zip", package = "climaru")
data_chunk <- restore_st_ids(dir_name = NULL, zip_name = meteo_zip)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.